@@ -1,21 +1,11 @@
-import os
+from pathlib import Path
 from typing import Optional
 
 import streamlit as st
 import streamlit.components.v1 as components
 
-# Create a _RELEASE constant. We'll set this to False while we're developing
-# the component, and True when we're ready to package and distribute it.
-_RELEASE = True
-
-if not _RELEASE:
-    _component_func = components.declare_component(
-        "st_keyup", url="http://localhost:3001"
-    )
-else:
-    parent_dir = os.path.dirname(os.path.abspath(__file__))
-    build_dir = os.path.join(parent_dir, "frontend/build")
-    _component_func = components.declare_component("st_keyup", path=build_dir)
+build_dir = Path(__file__).parent.absolute() / "frontend"
+_component_func = components.declare_component("st_keyup", path=str(build_dir))
 
 
 def st_keyup(
@@ -68,5 +58,4 @@ def main():
 
 
 if __name__ == "__main__":
-    if not _RELEASE:
-        main()
+    main()
